@@ -39,6 +39,8 @@ GCC options
 -std=c99: Use C99 standard
 -lm: Link math library
 -lc: Link C standard library
+-march=native: Optimize for the current CPU
+-O3: Optimize for speed
 
 MSVC options
 
@@ -47,10 +49,10 @@ Compiler type is determined by the value of sys.platform.
 '''
 if sys.platform == "linux" or sys.platform == "linux2":
     # linux
-    extra_compile_args = ["-std=c99", "-lm", "-lc"]
+    extra_compile_args = ["-std=c99", "-lm", "-lc", "-O3"]
 else:
     # MSVC is already c99 compliant, so no need to specify
-    extra_compile_args = []
+    extra_compile_args = None
 
 # Include only the top-level header files.
 ffi.set_source("trajectorize._c_extension",
